@@ -35,9 +35,9 @@ SEXP sum2(SEXP x, SEXP idxs, SEXP naRm, SEXP mode) {
 
   /* Dispatch to low-level C function */
   if (isReal(x)) {
-    sum = sum2_dbl[idxsType](REAL(x), nx, cidxs, nidxs, narm, mode2);
+    sum = sum2_dbl[idxsType](REAL(x), nx, cidxs, nidxs, narm);
   } else if (isInteger(x) || isLogical(x)) {
-    sum = sum2_int[idxsType](INTEGER(x), nx, cidxs, nidxs, narm, mode2);
+    sum = sum2_int[idxsType](INTEGER(x), nx, cidxs, nidxs, narm);
   }
 
 
